VaultActions

Enum VaultActions 

pub enum VaultActions {
Show 30 variants Initialize { token_mint: String, deposit_fee_bps: u16, withdrawal_fee_bps: u16, reward_fee_bps: u16, decimals: u8, initialize_token_amount: u64, vrt_mint_address_file_path: Option<PathBuf>, }, CreateTokenMetadata { vault: String, name: String, symbol: String, uri: String, }, UpdateTokenMetadata { vault: String, name: String, symbol: String, uri: String, }, InitializeVaultUpdateStateTracker { vault: String, }, CrankVaultUpdateStateTracker { vault: String, operator: String, }, CloseVaultUpdateStateTracker { vault: String, ncn_epoch: Option<u64>, }, MintVRT { vault: String, amount_in: u64, min_amount_out: u64, }, InitializeOperatorDelegation { vault: String, operator: String, }, DelegateToOperator { vault: String, operator: String, amount: u64, }, CooldownOperatorDelegation { vault: String, operator: String, amount: u64, }, InitializeVaultNcnTicket { vault: String, ncn: String, }, WarmupVaultNcnTicket { vault: String, ncn: String, }, CooldownVaultNcnTicket { vault: String, ncn: String, }, EnqueueWithdrawal { vault: String, amount: u64, }, ChangeWithdrawalTicketOwner { vault: Pubkey, old_ticket_owner_keypair: String, new_ticket_owner: Pubkey, }, BurnWithdrawalTicket { vault: String, }, GetVaultUpdateStateTracker { vault: String, }, GetOperatorDelegations { vault: String, }, GetOperatorDelegation { vault: String, operator: String, }, GetWithdrawalTicket { vault: String, staker: Option<String>, }, Get { pubkey: String, }, List, SetAdmin { vault: Pubkey, old_admin_keypair: String, new_admin_keypair: String, }, SetCapacity { vault: String, amount: u64, }, SetFees { vault: Pubkey, deposit_fee_bps: Option<u16>, withdrawal_fee_bps: Option<u16>, reward_fee_bps: Option<u16>, }, SetIsPaused { vault: Pubkey, set_pause: bool, }, SetSecondaryAdmin { vault: Pubkey, new_admin: Pubkey, set_delegation_admin: bool, set_operator_admin: bool, set_ncn_admin: bool, set_slasher_admin: bool, set_capacity_admin: bool, set_fee_wallet: bool, set_mint_burn_admin: bool, set_delegate_asset_admin: bool, set_fee_admin: bool, set_metadata_admin: bool, }, UpdateVaultBalance { vault: Pubkey, }, DelegateTokenAccount { vault: String, delegate: String, token_mint: String, token_account: String, }, DelegatedTokenTransfer { token_account: String, recipient_pubkey: String, amount: u64, },
}
Vault commands

Variants



Initialize

Creates a new vault

Fields

token_mint: String

The token which is allowed to be deposited into the vault

deposit_fee_bps: u16

The deposit fee in bips

withdrawal_fee_bps: u16

The withdrawal fee in bips

reward_fee_bps: u16

The reward fee in bips

decimals: u8

The decimals of the token

initialize_token_amount: u64

The amount of tokens to initialize the vault with ( in the smallest unit )

vrt_mint_address_file_path: Option<PathBuf>

The file path of VRT mint address



CreateTokenMetadata

Creates token metadata for the vault’s LRT token

Fields

vault: String

The vault pubkey

name: String

The name of the token

symbol: String

The symbol of the token

uri: String

The URI for the token metadata



UpdateTokenMetadata

Fields

vault: String

The vault pubkey

name: String

The name of the token

symbol: String

The symbol of the token

uri: String

The URI for the token metadata



InitializeVaultUpdateStateTracker

Starts the vault update cycle

Fields

vault: String

Vault account



CrankVaultUpdateStateTracker

Cranks the vault update state tracker, needs to be run per operator

Fields

vault: String

Vault account

operator: String

Operator account



CloseVaultUpdateStateTracker

Ends the vault update cycle

Fields

vault: String

Vault account

ncn_epoch: Option<u64>

Optional NCN epoch to close



MintVRT

Mints VRT tokens

Fields

vault: String

Vault account

amount_in: u64

Amount to deposit

min_amount_out: u64

Minimum amount of VRT to mint



InitializeOperatorDelegation

Sets up the delegations for an operator

Fields

vault: String

Vault account

operator: String

Operator account



DelegateToOperator

Delegates tokens to an operator

Fields

vault: String

Vault account

operator: String

Operator account

amount: u64

Amount to delegate



CooldownOperatorDelegation

Cooldown delegation for an operator

Fields

vault: String

Vault account

operator: String

Operator account

amount: u64

Amount to cooldown



InitializeVaultNcnTicket

Initialize Vault NCN Ticket

Fields

vault: String

Vault account

ncn: String

NCN account



WarmupVaultNcnTicket

Warmup Vault NCN Ticket

Fields

vault: String

Vault account

ncn: String

NCN account



CooldownVaultNcnTicket

Cooldown Vault NCN Ticket

Fields

vault: String

Vault account

ncn: String

NCN account



EnqueueWithdrawal

Starts the withdrawal process

Fields

vault: String

Vault account

amount: u64

Amount to withdraw



ChangeWithdrawalTicketOwner

Change withdrawal ticket owner

Fields

vault: Pubkey

The vault pubkey

old_ticket_owner_keypair: String

The old ticket owner keypair

new_ticket_owner: Pubkey

The new ticket owner pubkey



BurnWithdrawalTicket

Burns the withdrawal ticket, ending the withdrawal process

Fields

vault: String

Vault account



GetVaultUpdateStateTracker

Gets the update state tracker for a vault

Fields

vault: String

Vault account



GetOperatorDelegations

Gets the operator delegations for a vault

Fields

vault: String

Vault account



GetOperatorDelegation

Gets the operator delegation for a vault

Fields

vault: String

Vault account

operator: String

Operator account



GetWithdrawalTicket

Fields

vault: String

Vault account

staker: Option<String>

Staker account



Get

Gets a vault

Fields

pubkey: String

The vault pubkey



List

List all vaults



SetAdmin

Set Admin

Fields

vault: Pubkey

The Vault pubkey

old_admin_keypair: String

Filepath or URL to a keypair of old admin

new_admin_keypair: String

Filepath or URL to a keypair of new admin



SetCapacity

Sets the deposit capacity in the vault

Fields

vault: String

The vault pubkey

amount: u64

The new capacity



SetFees

Sets the fees in the vault

Fields

vault: Pubkey

The vault pubkey

deposit_fee_bps: Option<u16>

The deposit fee BPS

withdrawal_fee_bps: Option<u16>

The withdrawal fee BPS

reward_fee_bps: Option<u16>

The reward fee BPS



SetIsPaused

Sets the vault’s pause state

Fields

vault: Pubkey

The vault pubkey

set_pause: bool

Set pause



SetSecondaryAdmin

Set Secondary Admin

Fields

vault: Pubkey

The vault pubkey

new_admin: Pubkey

The new admin pubkey

set_delegation_admin: bool

Set delegation_admin

set_operator_admin: bool

Set operator_admin

set_ncn_admin: bool

Set ncn_admin

set_slasher_admin: bool

Set slasher_admin

set_capacity_admin: bool

Set capacity_admin

set_fee_wallet: bool

Set fee_wallet

set_mint_burn_admin: bool

Set mint_burn_admin

set_delegate_asset_admin: bool

Set delegate_asset_admin

set_fee_admin: bool

Set fee_admin

set_metadata_admin: bool

Set metadata_admin



UpdateVaultBalance

Update Vault Balance

Fields

vault: Pubkey

The vault pubkey



DelegateTokenAccount

Delegate a token account

Fields

vault: String

The vault pubkey

delegate: String

The delegate account

token_mint: String

The token mint

token_account: String

The token account



DelegatedTokenTransfer

Transfer a token account

Fields

token_account: String

The token account

recipient_pubkey: String

The recipient pubkey

amount: u64

The amount to transfer