pub struct VaultCliHandler { /* private fields */ }Implementations
Sourceimpl VaultCliHandler
impl VaultCliHandler
pub const fn new( cli_config: CliConfig, restaking_program_id: Pubkey, vault_program_id: Pubkey, print_tx: bool, print_json: bool, print_json_with_reserves: bool, ) -> Self
pub async fn handle(&self, action: VaultCommands) -> Result<()>
pub async fn initialize_config( &self, program_fee_bps: u16, program_fee_wallet: Pubkey, ) -> Result<()>
pub async fn initialize_vault( &self, token_mint: String, deposit_fee_bps: u16, withdrawal_fee_bps: u16, reward_fee_bps: u16, decimals: u8, initialize_token_amount: u64, vrt_mint_address_file_path: Option<PathBuf>, ) -> Result<()>
pub async fn initialize_vault_update_state_tracker( &self, vault: String, ) -> Result<()>
pub async fn crank_vault_update_state_tracker( &self, vault: String, operator: String, ) -> Result<()>
pub async fn close_vault_update_state_tracker( &self, vault: String, ncn_epoch: Option<u64>, ) -> Result<()>
pub async fn mint_vrt( &self, vault: String, amount_in: u64, min_amount_out: u64, ) -> Result<()>
pub async fn initialize_vault_ncn_ticket( &self, vault: String, ncn: String, ) -> Result<()>
pub async fn warmup_vault_ncn_ticket( &self, vault: String, ncn: String, ) -> Result<()>
pub async fn cooldown_vault_ncn_ticket( &self, vault: String, ncn: String, ) -> Result<()>
pub async fn initialize_vault_operator_delegation( &self, vault: String, operator: String, ) -> Result<()>
pub async fn delegate_to_operator( &self, vault: String, operator: String, amount: u64, ) -> Result<()>
pub async fn cooldown_operator_delegation( &self, vault: String, operator: String, amount: u64, ) -> Result<()>
pub async fn delegate_token_account( &self, vault: String, delegate: String, token_mint: String, token_account: String, ) -> Result<()>
pub async fn delegated_token_transfer( &self, token_account: String, recipient_pubkey: String, amount: u64, ) -> Result<()>
pub async fn enqueue_withdrawal(&self, vault: String, amount: u64) -> Result<()>
Sourcepub async fn change_withdrawal_ticket_owner(
&self,
vault: &Pubkey,
old_ticket_owner: &str,
new_ticket_owner: &Pubkey,
) -> Result<()>
pub async fn change_withdrawal_ticket_owner( &self, vault: &Pubkey, old_ticket_owner: &str, new_ticket_owner: &Pubkey, ) -> Result<()>
Changes the owner of a withdrawal ticket
Transfers ownership of a vault staker withdrawal ticket from one account to another. This operation requires the signature of both the current ticket owner and the signer configured in the client.
pub async fn burn_withdrawal_ticket(&self, vault: String) -> Result<()>
pub async fn get_vault(&self, pubkey: String) -> Result<()>
pub async fn list_vaults(&self) -> Result<()>
pub async fn get_vault_update_state_tracker(&self, vault: String) -> Result<()>
pub async fn get_vault_operator_delegations( &self, vault: String, operator: Option<String>, ) -> Result<()>
pub async fn get_withdrawal_ticket( &self, vault: String, staker: Option<String>, ) -> Result<()>